/*-------------------------------------------------------------------------+
| Copyright 2018 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.af3.platform.raspberry.ui.editpart;

import org.eclipse.gef.EditPart;
import org.eclipse.swt.graphics.Color;
import org.fortiss.af3.platform.model.PlatformConnectorUnit;
import org.fortiss.af3.platform.raspberry.model.ActuatorPWM;
import org.fortiss.af3.platform.raspberry.model.CanBus;
import org.fortiss.af3.platform.raspberry.model.CanConnector;
import org.fortiss.af3.platform.raspberry.model.ConsoleOutput;
import org.fortiss.af3.platform.raspberry.model.RaspberryPi;
import org.fortiss.af3.platform.raspberry.model.brick.UIDUnit;
import org.fortiss.af3.platform.raspberry.model.camera.CameraDetectionStateLeft;
import org.fortiss.af3.platform.raspberry.model.camera.CameraDetectionStateRight;
import org.fortiss.af3.platform.raspberry.model.camera.CameraDistanceLeft;
import org.fortiss.af3.platform.raspberry.model.camera.CameraDistanceRight;
import org.fortiss.af3.platform.raspberry.model.camera.CameraYawAngle;
import org.fortiss.af3.platform.raspberry.model.controlcenter.ControlCenterDownstreamInput;
import org.fortiss.af3.platform.raspberry.model.controlcenter.ControlCenterUpstreamOutput;
import org.fortiss.af3.platform.raspberry.model.gamepad.GamepadReceiverBase;
import org.fortiss.af3.platform.raspberry.model.motorcontrol.MotorControlInput;
import org.fortiss.af3.platform.raspberry.model.motorcontrol.MotorControlOutput;
import org.fortiss.af3.platform.raspberry.model.rumblepad.RumbleMagnitudeStrong;
import org.fortiss.af3.platform.raspberry.model.rumblepad.RumbleMagnitudeWeak;
import org.fortiss.af3.platform.raspberry.model.rumblepad.RumblepadReceiverBase;
import org.fortiss.af3.platform.raspberry.model.rumblepad.SimpleRumbleFeature;
import org.fortiss.af3.platform.raspberry.model.v2v.V2VInput;
import org.fortiss.af3.platform.raspberry.model.v2v.V2VOuput;
import org.fortiss.af3.platform.ui.DefaultStyle;
import org.fortiss.af3.platform.ui.editpart.generic.ExecutionUnitEditPart;
import org.fortiss.af3.platform.ui.editpart.generic.StickyPlatformConnectorUnitEditPart;
import org.fortiss.af3.platform.ui.editpart.generic.TransmissionUnitDefaultEditPart;
import org.fortiss.tooling.kernel.ui.extension.IEditPartFactory;

/** {@link IEditPartFactory} for {@link RaspberryPi} model elements. */
public class RaspberryPiEditPartFactory implements IEditPartFactory {
	/** {@inheritDoc} */
	@Override
	public EditPart createEditPart(EditPart context, Object model) {
		if(model instanceof RaspberryPi) {
			return new ExecutionUnitEditPart((RaspberryPi)model) {
				/** {@inheritDoc} */
				@Override
				protected Color getBackgroundColor() {
					return DefaultStyle.EU_BACKGROUND;
				}

				/** {@inheritDoc} */
				@Override
				protected Color getForegroundColor() {
					return DefaultStyle.EU_FOREGROUND;
				}
			};
		} else if(model instanceof CanBus) {
			return new TransmissionUnitDefaultEditPart((CanBus)model);
		} else if(model instanceof CanConnector || model instanceof ActuatorPWM ||
				model instanceof ConsoleOutput || model instanceof GamepadReceiverBase ||
				model instanceof RumblepadReceiverBase || model instanceof SimpleRumbleFeature ||
				model instanceof RumbleMagnitudeWeak || model instanceof RumbleMagnitudeStrong ||
				model instanceof UIDUnit || model instanceof MotorControlInput ||
				model instanceof MotorControlOutput || model instanceof CameraDistanceLeft ||
				model instanceof CameraDistanceRight || model instanceof CameraYawAngle ||
				model instanceof CameraDetectionStateLeft ||
				model instanceof CameraDetectionStateRight ||
				model instanceof ControlCenterUpstreamOutput ||
				model instanceof ControlCenterDownstreamInput || model instanceof V2VInput ||
				model instanceof V2VOuput) {
			return new StickyPlatformConnectorUnitEditPart((PlatformConnectorUnit)model);
		}
		return null;
	}
}
