/*-------------------------------------------------------------------------+
| Copyright 2018 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.af3.platform.raspberry.generator.extension.brick;

import org.eclipse.emf.ecore.EObject;
import org.fortiss.af3.platform.raspberry.generator.extension.library.BrickLibraryGeneratorExtensionBase;
import org.fortiss.af3.platform.raspberry.generator.framework.ISingletonInitializationGeneratorExtension;

/**
 * Base class for generator extensions of the Brick and Bricklets hardware.
 * 
 * @author hoelzl
 */
abstract class BrickGeneratorExtensionBase<T extends EObject> extends
		BrickLibraryGeneratorExtensionBase<T> implements ISingletonInitializationGeneratorExtension {
	/** Constructor. */
	public BrickGeneratorExtensionBase(T modelElement) {
		super(modelElement);
	}

	/** {@inheritDoc} */
	@Override
	public String getSingletonIdentifier() {
		return "ip_connection.h";
	}

	/** {@inheritDoc} */
	@Override
	public String getSingletonVariableDeclarationCode(String singletonPostfix) {
		return "static IPConnection " + getConnectionVariable(singletonPostfix) + ";\n";
	}

	/** {@inheritDoc} */
	@Override
	public String getSingletonAuxiliaryFunctions(String singletonPostfix) {
		return null;
	}

	/** {@inheritDoc} */
	@Override
	public String getSingletonInitializationCode(String singletonPostfix) {
		StringBuilder sb = new StringBuilder();
		String connectionVariable = getConnectionVariable(singletonPostfix);
		sb.append("ipcon_create(&" + connectionVariable + ");\n");
		sb.append("if(ipcon_connect(&" + connectionVariable + ", BRICK_HOST, BRICK_PORT) < 0) {\n");
		sb.append("perror(\"Failed to connect to brick sub-system.\");\n");
		sb.append("return 1;\n");
		sb.append("}\n\n");
		return sb.toString();
	}

	/** Returns the connection variable name. */
	protected final String getConnectionVariable(String postfix) {
		return "brick_connection_" + postfix;
	}
}
